@@ -21,7 +21,7 @@ ARGINFO_NONE_RETURN_DS(     Collection_copy, Collection);
 ARGINFO_NONE(               Collection_clear);
 ARGINFO_NONE_RETURN_LONG(   Collection_count);
 ARGINFO_NONE_RETURN_BOOL(   Collection_isEmpty);
-ARGINFO_NONE(               Collection_jsonSerialize);
+ARGINFO_NONE_RETURN_TYPE(   Collection_jsonSerialize, IS_MIXED);
 ARGINFO_NONE_RETURN_ARRAY(  Collection_toArray);
 
 void php_ds_register_collection();
