@@ -178,11 +178,15 @@ METHOD(slice)
 {
     ds_set_t *set = THIS_DS_SET();
 
-    if (ZEND_NUM_ARGS() > 1) {
-        PARSE_LONG_AND_LONG(index, length);
-        RETURN_DS_SET(ds_set_slice(set, index, length));
+    PARSE_LONG_AND_OPTIONAL_ZVAL(index, length);
+
+    if (ZEND_NUM_ARGS() > 1 && Z_TYPE_P(length) != IS_NULL) {
+        if (Z_TYPE_P(length) != IS_LONG) {
+            INTEGER_LENGTH_REQUIRED(length);
+        } else {
+            RETURN_DS_SET(ds_set_slice(set, index, Z_LVAL_P(length)));
+        }
     } else {
-        PARSE_LONG(index);
         RETURN_DS_SET(ds_set_slice(set, index, DS_SET_SIZE(set)));
     }
 }
