@@ -7,7 +7,8 @@
 typedef struct _ds_queue_iterator_t {
     zend_object_iterator     intern;
     zend_long                position;
-    php_ds_queue_t          *queue;
+    zend_object             *object;
+    ds_queue_t              *queue;
 } ds_queue_iterator_t;
 
 zend_object_iterator *php_ds_queue_get_iterator(zend_class_entry *ce, zval *object, int by_ref);
